==> zio-aws-workspaces_2.13-5.17.295.14-sources.jar: zio/aws/workspaces/model/CreateWorkspaceImageResponse.scala <==
package zio.aws.workspaces.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.workspaces.model.primitives.{
  AwsAccount,
  Timestamp,
  WorkspaceImageName,
  WorkspaceImageId,
  WorkspaceImageDescription
}
import scala.jdk.CollectionConverters._
final case class CreateWorkspaceImageResponse(
    imageId: Optional[WorkspaceImageId] = Optional.Absent,
    name: Optional[WorkspaceImageName] = Optional.Absent,
    description: Optional[WorkspaceImageDescription] = Optional.Absent,
    operatingSystem: Optional[zio.aws.workspaces.model.OperatingSystem] =
      Optional.Absent,
    state: Optional[zio.aws.workspaces.model.WorkspaceImageState] =
      Optional.Absent,
    requiredTenancy: Optional[
      zio.aws.workspaces.model.WorkspaceImageRequiredTenancy
    ] = Optional.Absent,
    created: Optional[Timestamp] = Optional.Absent,
    ownerAccountId: Optional[AwsAccount] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageResponse = {
    import CreateWorkspaceImageResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageResponse
      .builder()
      .optionallyWith(
        imageId.map(value => WorkspaceImageId.unwrap(value): java.lang.String)
      )(_.imageId)
      .optionallyWith(
        name.map(value => WorkspaceImageName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        description.map(value =>
          WorkspaceImageDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(operatingSystem.map(value => value.buildAwsValue()))(
        _.operatingSystem
      )
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(requiredTenancy.map(value => value.unwrap))(
        _.requiredTenancy
      )
      .optionallyWith(created.map(value => Timestamp.unwrap(value): Instant))(
        _.created
      )
      .optionallyWith(
        ownerAccountId.map(value => AwsAccount.unwrap(value): java.lang.String)
      )(_.ownerAccountId)
      .build()
  }
  def asReadOnly
      : zio.aws.workspaces.model.CreateWorkspaceImageResponse.ReadOnly =
    zio.aws.workspaces.model.CreateWorkspaceImageResponse.wrap(buildAwsValue())
}
object CreateWorkspaceImageResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.CreateWorkspaceImageResponse =
      zio.aws.workspaces.model.CreateWorkspaceImageResponse(
        imageId.map(value => value),
        name.map(value => value),
        description.map(value => value),
        operatingSystem.map(value => value.asEditable),
        state.map(value => value),
        requiredTenancy.map(value => value),
        created.map(value => value),
        ownerAccountId.map(value => value)
      )
    def imageId: Optional[WorkspaceImageId]
    def name: Optional[WorkspaceImageName]
    def description: Optional[WorkspaceImageDescription]
    def operatingSystem
        : Optional[zio.aws.workspaces.model.OperatingSystem.ReadOnly]
    def state: Optional[zio.aws.workspaces.model.WorkspaceImageState]
    def requiredTenancy
        : Optional[zio.aws.workspaces.model.WorkspaceImageRequiredTenancy]
    def created: Optional[Timestamp]
    def ownerAccountId: Optional[AwsAccount]
    def getImageId: ZIO[Any, AwsError, WorkspaceImageId] =
      AwsError.unwrapOptionField("imageId", imageId)
    def getName: ZIO[Any, AwsError, WorkspaceImageName] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, WorkspaceImageDescription] =
      AwsError.unwrapOptionField("description", description)
    def getOperatingSystem: ZIO[
      Any,
      AwsError,
      zio.aws.workspaces.model.OperatingSystem.ReadOnly
    ] = AwsError.unwrapOptionField("operatingSystem", operatingSystem)
    def getState
        : ZIO[Any, AwsError, zio.aws.workspaces.model.WorkspaceImageState] =
      AwsError.unwrapOptionField("state", state)
    def getRequiredTenancy: ZIO[
      Any,
      AwsError,
      zio.aws.workspaces.model.WorkspaceImageRequiredTenancy
    ] = AwsError.unwrapOptionField("requiredTenancy", requiredTenancy)
    def getCreated: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("created", created)
    def getOwnerAccountId: ZIO[Any, AwsError, AwsAccount] =
      AwsError.unwrapOptionField("ownerAccountId", ownerAccountId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageResponse
  ) extends zio.aws.workspaces.model.CreateWorkspaceImageResponse.ReadOnly {
    override val imageId: Optional[WorkspaceImageId] = zio.aws.core.internal
      .optionalFromNullable(impl.imageId())
      .map(value => zio.aws.workspaces.model.primitives.WorkspaceImageId(value))
    override val name: Optional[WorkspaceImageName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value =>
        zio.aws.workspaces.model.primitives.WorkspaceImageName(value)
      )
    override val description: Optional[WorkspaceImageDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.workspaces.model.primitives.WorkspaceImageDescription(value)
        )
    override val operatingSystem
        : Optional[zio.aws.workspaces.model.OperatingSystem.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.operatingSystem())
        .map(value => zio.aws.workspaces.model.OperatingSystem.wrap(value))
    override val state: Optional[zio.aws.workspaces.model.WorkspaceImageState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.state())
        .map(value => zio.aws.workspaces.model.WorkspaceImageState.wrap(value))
    override val requiredTenancy
        : Optional[zio.aws.workspaces.model.WorkspaceImageRequiredTenancy] =
      zio.aws.core.internal
        .optionalFromNullable(impl.requiredTenancy())
        .map(value =>
          zio.aws.workspaces.model.WorkspaceImageRequiredTenancy.wrap(value)
        )
    override val created: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.created())
      .map(value => zio.aws.workspaces.model.primitives.Timestamp(value))
    override val ownerAccountId: Optional[AwsAccount] = zio.aws.core.internal
      .optionalFromNullable(impl.ownerAccountId())
      .map(value => zio.aws.workspaces.model.primitives.AwsAccount(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageResponse
  ): zio.aws.workspaces.model.CreateWorkspaceImageResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-workspaces_3-6.20.162.2-sources.jar: zio/aws/workspaces/model/CreateWorkspaceImageResponse.scala <==
package zio.aws.workspaces.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.workspaces.model.primitives.{
  AwsAccount,
  Timestamp,
  WorkspaceImageName,
  WorkspaceImageId,
  WorkspaceImageDescription
}
import scala.jdk.CollectionConverters.*
final case class CreateWorkspaceImageResponse(
    imageId: Optional[WorkspaceImageId] = Optional.Absent,
    name: Optional[WorkspaceImageName] = Optional.Absent,
    description: Optional[WorkspaceImageDescription] = Optional.Absent,
    operatingSystem: Optional[zio.aws.workspaces.model.OperatingSystem] =
      Optional.Absent,
    state: Optional[zio.aws.workspaces.model.WorkspaceImageState] =
      Optional.Absent,
    requiredTenancy: Optional[
      zio.aws.workspaces.model.WorkspaceImageRequiredTenancy
    ] = Optional.Absent,
    created: Optional[Timestamp] = Optional.Absent,
    ownerAccountId: Optional[AwsAccount] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageResponse = {
    import CreateWorkspaceImageResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageResponse
      .builder()
      .optionallyWith(
        imageId.map(value => WorkspaceImageId.unwrap(value): java.lang.String)
      )(_.imageId)
      .optionallyWith(
        name.map(value => WorkspaceImageName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        description.map(value =>
          WorkspaceImageDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .optionallyWith(operatingSystem.map(value => value.buildAwsValue()))(
        _.operatingSystem
      )
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(requiredTenancy.map(value => value.unwrap))(
        _.requiredTenancy
      )
      .optionallyWith(created.map(value => Timestamp.unwrap(value): Instant))(
        _.created
      )
      .optionallyWith(
        ownerAccountId.map(value => AwsAccount.unwrap(value): java.lang.String)
      )(_.ownerAccountId)
      .build()
  }
  def asReadOnly
      : zio.aws.workspaces.model.CreateWorkspaceImageResponse.ReadOnly =
    zio.aws.workspaces.model.CreateWorkspaceImageResponse.wrap(buildAwsValue())
}
object CreateWorkspaceImageResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.CreateWorkspaceImageResponse =
      zio.aws.workspaces.model.CreateWorkspaceImageResponse(
        imageId.map(value => value),
        name.map(value => value),
        description.map(value => value),
        operatingSystem.map(value => value.asEditable),
        state.map(value => value),
        requiredTenancy.map(value => value),
        created.map(value => value),
        ownerAccountId.map(value => value)
      )
    def imageId: Optional[WorkspaceImageId]
    def name: Optional[WorkspaceImageName]
    def description: Optional[WorkspaceImageDescription]
    def operatingSystem
        : Optional[zio.aws.workspaces.model.OperatingSystem.ReadOnly]
    def state: Optional[zio.aws.workspaces.model.WorkspaceImageState]
    def requiredTenancy
        : Optional[zio.aws.workspaces.model.WorkspaceImageRequiredTenancy]
    def created: Optional[Timestamp]
    def ownerAccountId: Optional[AwsAccount]
    def getImageId: ZIO[Any, AwsError, WorkspaceImageId] =
      AwsError.unwrapOptionField("imageId", imageId)
    def getName: ZIO[Any, AwsError, WorkspaceImageName] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, WorkspaceImageDescription] =
      AwsError.unwrapOptionField("description", description)
    def getOperatingSystem: ZIO[
      Any,
      AwsError,
      zio.aws.workspaces.model.OperatingSystem.ReadOnly
    ] = AwsError.unwrapOptionField("operatingSystem", operatingSystem)
    def getState
        : ZIO[Any, AwsError, zio.aws.workspaces.model.WorkspaceImageState] =
      AwsError.unwrapOptionField("state", state)
    def getRequiredTenancy: ZIO[
      Any,
      AwsError,
      zio.aws.workspaces.model.WorkspaceImageRequiredTenancy
    ] = AwsError.unwrapOptionField("requiredTenancy", requiredTenancy)
    def getCreated: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("created", created)
    def getOwnerAccountId: ZIO[Any, AwsError, AwsAccount] =
      AwsError.unwrapOptionField("ownerAccountId", ownerAccountId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageResponse
  ) extends zio.aws.workspaces.model.CreateWorkspaceImageResponse.ReadOnly {
    override val imageId: Optional[WorkspaceImageId] = zio.aws.core.internal
      .optionalFromNullable(impl.imageId())
      .map(value => zio.aws.workspaces.model.primitives.WorkspaceImageId(value))
    override val name: Optional[WorkspaceImageName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value =>
        zio.aws.workspaces.model.primitives.WorkspaceImageName(value)
      )
    override val description: Optional[WorkspaceImageDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.workspaces.model.primitives.WorkspaceImageDescription(value)
        )
    override val operatingSystem
        : Optional[zio.aws.workspaces.model.OperatingSystem.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.operatingSystem())
        .map(value => zio.aws.workspaces.model.OperatingSystem.wrap(value))
    override val state: Optional[zio.aws.workspaces.model.WorkspaceImageState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.state())
        .map(value => zio.aws.workspaces.model.WorkspaceImageState.wrap(value))
    override val requiredTenancy
        : Optional[zio.aws.workspaces.model.WorkspaceImageRequiredTenancy] =
      zio.aws.core.internal
        .optionalFromNullable(impl.requiredTenancy())
        .map(value =>
          zio.aws.workspaces.model.WorkspaceImageRequiredTenancy.wrap(value)
        )
    override val created: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.created())
      .map(value => zio.aws.workspaces.model.primitives.Timestamp(value))
    override val ownerAccountId: Optional[AwsAccount] = zio.aws.core.internal
      .optionalFromNullable(impl.ownerAccountId())
      .map(value => zio.aws.workspaces.model.primitives.AwsAccount(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.CreateWorkspaceImageResponse
  ): zio.aws.workspaces.model.CreateWorkspaceImageResponse.ReadOnly =
    new Wrapper(impl)
}
